/***************************************************************
 *
 * Copyright (C) 1990-2007, Condor Team, Computer Sciences Department,
 * University of Wisconsin-Madison, WI.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License.  You may
 * obtain a copy of the License at
 * 
 *    http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ***************************************************************/

#include "condor_common.h"
#if HAVE_EXT_GSOAP
#include "string_list.h"
#include "file_transfer.h"

#include "loose_file_transfer.h"

LooseFileTransfer::LooseFileTransfer()
{
  FileTransfer();
}

bool
LooseFileTransfer::getInputFiles(StringList & inputFileList)
{
  char *buffer;

  InputFiles->rewind();
  while (NULL != (buffer = InputFiles->next())) {
    inputFileList.append(buffer);
  }

  return true;
}
#endif
